@@ -1,7 +1,7 @@
 /*
   Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-  2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
-  Foundation, Inc.
+  2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Free
+  Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -51,6 +51,7 @@
 #include <setjmp.h>
 #include <getopt.h>
 #include <sys/types.h>
+#include <netinet/in.h>
 
 extern void cwd (const char *);
 extern int checkuser (const char *filename, const char *name);
@@ -88,8 +89,10 @@ extern char *sgetsave (const char *);
 
 /* Exported from ftpd.c.  */
 jmp_buf errcatch;
-extern struct sockaddr_in data_dest;
-extern struct sockaddr_in his_addr;
+extern struct sockaddr_storage data_dest;
+extern socklen_t data_dest_len;
+extern struct sockaddr_storage his_addr;
+extern socklen_t his_addrlen;
 extern int logged_in;
 extern struct passwd *pw;
 extern int guest;
@@ -110,8 +113,8 @@ extern char tmpline[];
 extern off_t restart_point;
 
 /* Exported from server_mode.c.  */
-extern int server_mode (const char *pidfile, struct sockaddr_in *phis_addr,
-			char *argv[]);
+extern int server_mode (const char *pidfile, struct sockaddr *phis_addr,
+			socklen_t *phis_addrlen, char *argv[]);
 
 /* Credential for the request.  */
 struct credentials
