@@ -1,7 +1,7 @@
 /* localhost.c - A slightly more convenient wrapper for gethostname
   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
-  Inc.
+  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Free Software
+  Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
