@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010,
-  2011 Free Software Foundation, Inc.
+  2011, 2012 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
